import ckan.plugins.toolkit as tk

CONF_DEFAULT_THEME = "ckanext.json_viewer.default_theme"
CONF_DEFAULT_VIEW_NAME = "ckanext.json_viewer.default_view_name"
CONF_DEFAULT_DESCRIPTION = "ckanext.json_viewer.default_description"
CONF_DEFAULT_MAX_HEIGHT = "ckanext.json_viewer.default_max_height"
CONF_DEFAULT_EXPAND = "ckanext.json_viewer.default_expand"
CONF_DEFAULT_INDENTATION = "ckanext.json_viewer.default_indentation"
CONF_DEFAULT_SHOW_DATA_TYPES = "ckanext.json_viewer.default_show_data_types"
CONF_DEFAULT_SHOW_TOOLBAR = "ckanext.json_viewer.default_show_toolbar"
CONF_DEFAULT_SHOW_COPY_BUTTON = "ckanext.json_viewer.default_show_copy_button"
CONF_DEFAULT_SHOW_SIZES = "ckanext.json_viewer.default_show_sizes"


class ExtConfig:
    """Configuration options for the JSON Viewer extension."""

    @classmethod
    def get_default_theme(cls) -> str:
        return tk.config[CONF_DEFAULT_THEME]

    @classmethod
    def get_default_view_name(cls) -> str:
        return tk.config[CONF_DEFAULT_VIEW_NAME]

    @classmethod
    def get_default_description(cls) -> str:
        return tk.config[CONF_DEFAULT_DESCRIPTION]

    @classmethod
    def get_default_max_height(cls) -> int:
        return tk.config[CONF_DEFAULT_MAX_HEIGHT]

    @classmethod
    def get_default_expand(cls) -> bool:
        return tk.asbool(tk.config[CONF_DEFAULT_EXPAND])

    @classmethod
    def get_default_indentation(cls) -> int:
        return tk.config[CONF_DEFAULT_INDENTATION]

    @classmethod
    def get_default_show_data_types(cls) -> bool:
        return tk.asbool(tk.config[CONF_DEFAULT_SHOW_DATA_TYPES])

    @classmethod
    def get_default_show_toolbar(cls) -> bool:
        return tk.asbool(tk.config[CONF_DEFAULT_SHOW_TOOLBAR])

    @classmethod
    def get_default_show_copy_button(cls) -> bool:
        return tk.asbool(tk.config[CONF_DEFAULT_SHOW_COPY_BUTTON])

    @classmethod
    def get_default_show_sizes(cls) -> bool:
        return tk.asbool(tk.config[CONF_DEFAULT_SHOW_SIZES])



from typing import Any

import ckan.plugins as p
import ckan.plugins.toolkit as tk
from ckan import types
from ckan.common import CKANConfig

import ckanext.resourceproxy.plugin as proxy

from ckanext.json_viewer.config import ExtConfig
from ckanext.json_viewer.logic.schema import get_preview_schema


@tk.blanket.helpers
@tk.blanket.config_declarations
class JsonViewerPlugin(p.SingletonPlugin):
    p.implements(p.IConfigurer)
    p.implements(p.IResourceView, inherit=True)

    # IConfigurer

    def update_config(self, config_: CKANConfig):
        tk.add_template_directory(config_, "templates")
        tk.add_resource("assets", "json_viewer")

    # IResourceView

    def info(self) -> dict[str, Any]:
        return {
            "name": "json_viewer",
            "title": "JSON Viewer",
            "icon": "fa fa-code",
            "iframed": False,
            "schema": get_preview_schema(),
            "preview_enabled": True,
            "default_title": ExtConfig.get_default_view_name(),
            "default_description": ExtConfig.get_default_description(),
        }

    def can_view(self, data_dict: dict[str, Any]) -> bool:
        return data_dict["resource"].get("format", "").lower() == "json"

    def setup_template_variables(
        self, context: types.Context, data_dict: dict[str, Any]
    ):
        default_view_data = {
            "title": ExtConfig.get_default_view_name(),
            "description": ExtConfig.get_default_description(),
            "max_height": ExtConfig.get_default_max_height(),
            "theme": ExtConfig.get_default_theme(),
            "expand": ExtConfig.get_default_expand(),
            "indentation": ExtConfig.get_default_indentation(),
            "show_data_types": ExtConfig.get_default_show_data_types(),
            "show_toolbar": ExtConfig.get_default_show_toolbar(),
            "show_copy_button": ExtConfig.get_default_show_copy_button(),
            "show_sizes": ExtConfig.get_default_show_sizes(),
        }

        for key, value in default_view_data.items():
            data_dict["resource_view"].setdefault(key, value)

        data_dict["resource_url"] = proxy.get_proxified_resource_url(data_dict)

        return data_dict

    def view_template(self, context: types.Context, data_dict: dict[str, Any]):
        return "json_view.html"

    def form_template(self, context: types.Context, data_dict: dict[str, Any]):
        return "json_form.html"



from __future__ import annotations

from ckanext.json_viewer import config


def json_viewer_get_default_theme() -> str:
    return config.get_default_theme()


def json_viewer_get_default_max_height() -> int:
    return config.get_default_max_height()


def json_viewer_get_theme_options() -> list[dict[str, str]]:
    return [
        {"value": theme, "text": theme}
        for theme in [
            "apathyashes",
            "atelier-dune-light",
            "atelier-dune",
            "atlas",
            "bespin",
            "black-metal",
            "brewer",
            "bright",
            "brogrammer",
            "brushtrees-dark",
            "brushtrees",
            "chalk",
            "circus",
            "classic-dark",
            "classic-light",
            "codeschool",
            "cupcake",
            "cupertino",
            "darcula",
            "darktooth",
            "default-dark",
            "default-light",
            "dracula",
            "eighties",
            "embers",
            "flat",
            "fruit-soda",
            "github",
            "google-dark",
            "google-light",
            "grayscale-dark",
            "grayscale-light",
            "greenscreen",
            "gruvbox-dark-hard",
            "gruvbox-light-hard",
            "harmonic-dark",
            "harmonic-light",
            "heetch-light",
            "heetch",
            "helios",
            "hopscotch",
            "horizon-dark",
            "ia-dark",
            "ia-light",
            "icy",
            "isotope",
            "macintosh",
            "marrakesh",
            "materia",
            "material-lighter",
            "material",
            "mellow-purple",
            "mexico-light",
            "mocha",
            "monokai",
            "nord",
            "ocean",
            "one-light",
            "onedark",
            "papercolor-dark",
            "papercolor-light",
            "paraiso",
            "pico",
            "pop",
            "railscasts",
            "seti",
            "solarized-dark",
            "solarized-light",
            "spacemacs",
            "summerfruit-dark",
            "summerfruit-light",
            "tomorrow-night",
            "tomorrow",
            "tube",
            "twilight",
            "woodland",
            "zenburn",
        ]
    ]
